export declare type RequestParameters = {
    url: string | string[];
    headers?: any;
    method?: 'GET' | 'POST' | 'PUT';
    body?: string;
    type?: 'string' | 'json' | 'arrayBuffer';
    credentials?: 'same-origin' | 'include';
    collectResourceTiming?: boolean;
    signal?: AbortSignal;
};
export declare type ResponseCallback<T> = (error?: Error | Error[] | null, data?: T | null, cacheControl?: string | null, expires?: string | null, xhr?: any) => void;
export declare class AJAXError extends Error {
    /**
     * The response's HTTP status code.
     */
    status: number;
    /**
     * The response's HTTP status text.
     */
    statusText: string;
    /**
     * The request's URL.
     */
    url: string;
    /**
     * The response's body.
     */
    body: Blob;
    constructor(status: number, statusText: string, url: string, body: Blob);
}
export interface IXhrRequestResult {
    err?: Error | Error[] | null;
    data?: any | null;
    cacheControl?: string | null;
    expires?: string | null;
    xhr?: any;
}
export declare function makeXMLHttpRequestPromise(requestParameters: RequestParameters): Promise<IXhrRequestResult>;
export declare const getJSON: (requestParameters: RequestParameters, callback: ResponseCallback<any>) => any;
export declare const getArrayBuffer: (requestParameters: RequestParameters, callback: ResponseCallback<ArrayBuffer>) => any;
export declare const postData: (requestParameters: RequestParameters, callback: ResponseCallback<string>) => any;
export declare const getImage: (requestParameters: RequestParameters, callback: ResponseCallback<HTMLImageElement | ImageBitmap | null>) => any;
export declare const arrayBufferToTiffImage: (data: ArrayBuffer, callback: (err?: Error | null, image?: any) => void, rasterParser: any) => Promise<void>;
export declare const getTiffImage: (requestParameters: RequestParameters, callback: ResponseCallback<HTMLImageElement | ImageBitmap | null>, rasterParser: any) => any;
export interface IRasterParser {
    rasterData: HTMLImageElement | ImageBitmap | null | undefined;
    width: number;
    height: number;
}
/**
 * @description 修改默认request中url、header等参数，返回修改后的参数
 * @property {function} callback 回调函数
 */
export declare const transformRequestConfig: {
    callback: (requestParameters: RequestParameters) => RequestParameters;
};
