var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/dom.ts
var dom_exports = {};
__export(dom_exports, {
  DPR: () => DPR,
  addClass: () => addClass,
  create: () => create,
  empty: () => empty,
  getClass: () => getClass,
  getContainer: () => getContainer,
  getViewPortScale: () => getViewPortScale,
  hasClass: () => hasClass,
  printCanvas: () => printCanvas,
  remove: () => remove,
  removeClass: () => removeClass,
  setClass: () => setClass,
  setTransform: () => setTransform,
  splitWords: () => splitWords,
  triggerResize: () => triggerResize,
  trim: () => trim
});
module.exports = __toCommonJS(dom_exports);
var import_mini_adapter = require("./mini-adapter");
function getContainer(domId) {
  let $dom = domId;
  if (typeof domId === "string") {
    $dom = import_mini_adapter.$window.document.getElementById(domId);
  }
  return $dom;
}
function trim(str) {
  return str.trim ? str.trim() : str.replace(/^\s+|\s+$/g, "");
}
function splitWords(str) {
  return trim(str).split(/\s+/);
}
function testProp(props) {
  var _a, _b, _c;
  const docStyle = (_c = (_b = (_a = import_mini_adapter.$window) == null ? void 0 : _a.document) == null ? void 0 : _b.documentElement) == null ? void 0 : _c.style;
  if (!docStyle) {
    return props[0];
  }
  for (const i in props) {
    if (props[i] && props[i] in docStyle) {
      return props[i];
    }
  }
  return props[0];
}
function create(tagName, className, container) {
  const el = import_mini_adapter.$window.document.createElement(tagName);
  el.className = className || "";
  if (container) {
    container.appendChild(el);
  }
  return el;
}
function remove(el) {
  const parent = el.parentNode;
  if (parent) {
    parent.removeChild(el);
  }
}
function addClass(el, name) {
  if (el.classList !== void 0) {
    const classes = splitWords(name);
    for (let i = 0, len = classes.length; i < len; i++) {
      el.classList.add(classes[i]);
    }
  } else if (!hasClass(el, name)) {
    const className = getClass(el);
    setClass(el, (className ? className + " " : "") + name);
  }
}
function removeClass(el, name) {
  if (el.classList !== void 0) {
    el.classList.remove(name);
  } else {
    setClass(el, trim((" " + getClass(el) + " ").replace(" " + name + " ", " ")));
  }
}
function hasClass(el, name) {
  if (el.classList !== void 0) {
    return el.classList.contains(name);
  }
  const className = getClass(el);
  return className.length > 0 && new RegExp("(^|\\s)" + name + "(\\s|$)").test(className);
}
function setClass(el, name) {
  if (el instanceof HTMLElement) {
    el.className = name;
  } else {
    el.className.baseVal = name;
  }
}
function getClass(el) {
  if (el instanceof SVGElement) {
    el = el.correspondingElement;
  }
  return el.className.baseVal === void 0 ? el.className : el.className.baseVal;
}
function empty(el) {
  while (el && el.firstChild) {
    el.removeChild(el.firstChild);
  }
}
var transformProp = testProp(["transform", "WebkitTransform"]);
function setTransform(el, value) {
  el.style[transformProp] = value;
}
function triggerResize() {
  if (typeof Event === "function") {
    import_mini_adapter.$window.dispatchEvent(new Event("resize"));
  } else {
    const evt = import_mini_adapter.$window.document.createEvent("UIEvents");
    evt.initUIEvent("resize", true, false, import_mini_adapter.$window, 0);
    import_mini_adapter.$window.dispatchEvent(evt);
  }
}
function printCanvas(canvas) {
  const css = [
    "padding: " + (canvas.height / 2 - 8) + "px " + canvas.width / 2 + "px;",
    "line-height: " + canvas.height + "px;",
    "background-image: url(" + canvas.toDataURL() + ");"
  ];
  console.log("%c\n", css.join(""));
}
function getViewPortScale() {
  var _a;
  const meta = import_mini_adapter.$window.document.querySelector('meta[name="viewport"]');
  if (!meta) {
    return 1;
  }
  const contentItems = (_a = meta.content) == null ? void 0 : _a.split(",");
  const scale = contentItems.find((item) => {
    const [key, value] = item.split("=");
    return key === "initial-scale";
  });
  return scale ? scale.split("=")[1] * 1 : 1;
}
var DPR = getViewPortScale() < 1 ? 1 : import_mini_adapter.$window.devicePixelRatio;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  DPR,
  addClass,
  create,
  empty,
  getClass,
  getContainer,
  getViewPortScale,
  hasClass,
  printCanvas,
  remove,
  removeClass,
  setClass,
  setTransform,
  splitWords,
  triggerResize,
  trim
});
